# Generated by Django 4.0 on 2022-01-04 07:06

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='RedjCaptchaModel',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False, unique=True)),
                ('text', models.CharField(max_length=12)),
                ('request_ip', models.CharField(max_length=40, null=True)),
                ('user_agent', models.CharField(max_length=250, null=True)),
                ('created_by', models.UUIDField(editable=False, null=True)),
                ('request_host', models.CharField(max_length=250, null=True)),
                ('deleted_at', models.DateTimeField(editable=False, null=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
            ],
            options={
                'db_table': 'redj_captchas',
                'ordering': ['-created_at'],
            },
        ),
    ]
